@@ -25,8 +25,8 @@
 (ert-deftest py-ert-virtualenv-filter-functionp-test-2b5yDV ()
   (should (functionp 'virtualenv-filter)))
 
-(ert-deftest py-ert-py-beginning-of-statement-p-functionp-test-sHNAQu ()
-  (should (functionp 'py-beginning-of-statement-p)))
+(ert-deftest py-ert-py--beginning-of-statement-p-functionp-test-sHNAQu ()
+  (should (functionp 'py--beginning-of-statement-p)))
 
 (ert-deftest py-ert-virtualenv-append-path-functionp-test-isLD43 ()
   (should (functionp 'virtualenv-append-path)))
@@ -85,9 +85,6 @@
 (ert-deftest py-ert--beginning-of-top-level-p-functionp-test-WYzTbw ()
   (should (functionp 'py--beginning-of-top-level-p)))
 
-(ert-deftest py-ert--beginning-of-statement-p-functionp-test-iGvK35 ()
-  (should (functionp 'py--beginning-of-statement-p)))
-
 (ert-deftest py-ert--beginning-of-expression-p-functionp-test-04H1WF ()
   (should (functionp 'py--beginning-of-expression-p)))
 
@@ -481,9 +478,6 @@
 (ert-deftest py-ert-toggle-split-window-function-functionp-test-sdTVyw ()
   (should (functionp 'py-toggle-split-window-function)))
 
-(ert-deftest py-ert--manage-windows-set-and-switch-functionp-test-GaPncc ()
-  (should (functionp 'py--manage-windows-set-and-switch)))
-
 (ert-deftest py-ert--alternative-split-windows-on-execute-function-functionp-test-cBDqBQ ()
   (should (functionp 'py--alternative-split-windows-on-execute-function)))
 
@@ -523,8 +517,8 @@
 (ert-deftest py-ert-execute-file-command-functionp-test-q8Pvch ()
   (should (functionp 'py-execute-file-command)))
 
-(ert-deftest py-ert--store-result-maybe-functionp-test-CUmPeV ()
-  (should (functionp 'py--store-result-maybe)))
+(ert-deftest py-ert--store-result-functionp-test-CUmPeV ()
+  (should (functionp 'py--store-result)))
 
 (ert-deftest py-ert--close-execution-functionp-test-8sPofz ()
   (should (functionp 'py--close-execution)))
@@ -589,9 +583,6 @@
 (ert-deftest py-ert--fix-start-functionp-test-0u6prE ()
   (should (functionp 'py--fix-start)))
 
-(ert-deftest py-ert-fetch-py-master-file-functionp-test-y4643i ()
-  (should (functionp 'py-fetch-py-master-file)))
-
 (ert-deftest py-ert-execute-import-or-reload-functionp-test-y6CSEX ()
   (should (functionp 'py-execute-import-or-reload)))
 
@@ -604,60 +595,21 @@
 (ert-deftest py-ert-execute-buffer-dedicated-functionp-test-m4vmoV ()
   (should (functionp 'py-execute-buffer-dedicated)))
 
-(ert-deftest py-ert-execute-buffer-switch-functionp-test-GII2Vz ()
-  (should (functionp 'py-execute-buffer-switch)))
-
-(ert-deftest py-ert-execute-buffer-no-switch-functionp-test-q2hNpe ()
-  (should (functionp 'py-execute-buffer-no-switch)))
-
-(ert-deftest py-ert-execute-buffer-dedicated-switch-functionp-test-86hTRS ()
-  (should (functionp 'py-execute-buffer-dedicated-switch)))
-
 (ert-deftest py-ert-execute-region-python-functionp-test-g59lNA ()
   (should (functionp 'py-execute-region-python)))
 
-(ert-deftest py-ert-execute-region-python-switch-functionp-test-K8ChJi ()
-  (should (functionp 'py-execute-region-python-switch)))
-
-(ert-deftest py-ert-execute-region-python-no-switch-functionp-test-ukU2C0 ()
-  (should (functionp 'py-execute-region-python-no-switch)))
-
 (ert-deftest py-ert-execute-region-python2-functionp-test-8c7pvI ()
   (should (functionp 'py-execute-region-python2)))
 
-(ert-deftest py-ert-execute-region-python2-switch-functionp-test-0Ekulq ()
-  (should (functionp 'py-execute-region-python2-switch)))
-
-(ert-deftest py-ert-execute-region-python2-no-switch-functionp-test-EXEU87 ()
-  (should (functionp 'py-execute-region-python2-no-switch)))
-
 (ert-deftest py-ert-execute-region-python3-functionp-test-m8bqUP ()
   (should (functionp 'py-execute-region-python3)))
 
-(ert-deftest py-ert-execute-region-python3-switch-functionp-test-yKpwDx ()
-  (should (functionp 'py-execute-region-python3-switch)))
-
-(ert-deftest py-ert-execute-region-python3-no-switch-functionp-test-SCzVif ()
-  (should (functionp 'py-execute-region-python3-no-switch)))
-
 (ert-deftest py-ert-execute-region-ipython-functionp-test-0GyaYW ()
   (should (functionp 'py-execute-region-ipython)))
 
-(ert-deftest py-ert-execute-region-ipython-switch-functionp-test-QrgtEE ()
-  (should (functionp 'py-execute-region-ipython-switch)))
-
-(ert-deftest py-ert-execute-region-ipython-no-switch-functionp-test-6rXwhm ()
-  (should (functionp 'py-execute-region-ipython-no-switch)))
-
 (ert-deftest py-ert-execute-region-jython-functionp-test-eSdxV3 ()
   (should (functionp 'py-execute-region-jython)))
 
-(ert-deftest py-ert-execute-region-jython-switch-functionp-test-gL4dwL ()
-  (should (functionp 'py-execute-region-jython-switch)))
-
-(ert-deftest py-ert-execute-region-jython-no-switch-functionp-test-CUk24s ()
-  (should (functionp 'py-execute-region-jython-no-switch)))
-
 (ert-deftest py-ert-process-file-functionp-test-kv2RaS ()
   (should (functionp 'py-process-file)))
 
@@ -901,41 +853,41 @@
 (ert-deftest py-ert-delete-minor-block-functionp-test-cjBlON ()
   (should (functionp 'py-delete-minor-block)))
 
-(ert-deftest py-ert-fill-string-django-functionp-test-quCIFx ()
-  (should (functionp 'py-fill-string-django)))
+;; (ert-deftest py-ert-fill-string-django-functionp-test-quCIFx ()
+;;   (should (functionp 'py-fill-string-django)))
 
-(ert-deftest py-ert-fill-string-onetwo-functionp-test-Ibzpwh ()
-  (should (functionp 'py-fill-string-onetwo)))
+;; (ert-deftest py-ert-fill-string-onetwo-functionp-test-Ibzpwh ()
+;;   (should (functionp 'py-fill-string-onetwo)))
 
-(ert-deftest py-ert-fill-string-pep-257-functionp-test-aygrm1 ()
-  (should (functionp 'py-fill-string-pep-257)))
+;; (ert-deftest py-ert-fill-string-pep-257-functionp-test-aygrm1 ()
+;;   (should (functionp 'py-fill-string-pep-257)))
 
-(ert-deftest py-ert-fill-string-pep-257-nn-functionp-test-yqP98K ()
-  (should (functionp 'py-fill-string-pep-257-nn)))
+;; (ert-deftest py-ert-fill-string-pep-257-nn-functionp-test-yqP98K ()
+;;   (should (functionp 'py-fill-string-pep-257-nn)))
 
-(ert-deftest py-ert-fill-string-symmetric-functionp-test-AveTXu ()
-  (should (functionp 'py-fill-string-symmetric)))
+;; (ert-deftest py-ert-fill-string-symmetric-functionp-test-AveTXu ()
+;;   (should (functionp 'py-fill-string-symmetric)))
 
-(ert-deftest py-ert-set-nil-docstring-style-functionp-test-gF1gJe ()
-  (should (functionp 'py-set-nil-docstring-style)))
+;; (ert-deftest py-ert-set-nil-docstring-style-functionp-test-gF1gJe ()
+;;   (should (functionp 'py-set-nil-docstring-style)))
 
-(ert-deftest py-ert-set-pep-257-nn-docstring-style-functionp-test-eouNvY ()
-  (should (functionp 'py-set-pep-257-nn-docstring-style)))
+;; (ert-deftest py-ert-set-pep-257-nn-docstring-style-functionp-test-eouNvY ()
+;;   (should (functionp 'py-set-pep-257-nn-docstring-style)))
 
-(ert-deftest py-ert-set-pep-257-docstring-style-functionp-test-M3JGeI ()
-  (should (functionp 'py-set-pep-257-docstring-style)))
+;; (ert-deftest py-ert-set-pep-257-docstring-style-functionp-test-M3JGeI ()
+;;   (should (functionp 'py-set-pep-257-docstring-style)))
 
-(ert-deftest py-ert-set-django-docstring-style-functionp-test-qqo0Xr ()
-  (should (functionp 'py-set-django-docstring-style)))
+;; (ert-deftest py-ert-set-django-docstring-style-functionp-test-qqo0Xr ()
+;;   (should (functionp 'py-set-django-docstring-style)))
 
-(ert-deftest py-ert-set-symmetric-docstring-style-functionp-test-gHuvOc ()
-  (should (functionp 'py-set-symmetric-docstring-style)))
+;; (ert-deftest py-ert-set-symmetric-docstring-style-functionp-test-gHuvOc ()
+;;   (should (functionp 'py-set-symmetric-docstring-style)))
 
-(ert-deftest py-ert-set-onetwo-docstring-style-functionp-test-eYonDX ()
-  (should (functionp 'py-set-onetwo-docstring-style)))
+;; (ert-deftest py-ert-set-onetwo-docstring-style-functionp-test-eYonDX ()
+;;   (should (functionp 'py-set-onetwo-docstring-style)))
 
-(ert-deftest py-ert-fill-comment-functionp-test-yq3wtI ()
-  (should (functionp 'py-fill-comment)))
+;; (ert-deftest py-ert-fill-comment-functionp-test-yq3wtI ()
+;;   (should (functionp 'py-fill-comment)))
 
 (ert-deftest py-ert-fill-labelled-string-functionp-test-ysNVft ()
   (should (functionp 'py-fill-labelled-string)))
@@ -949,23 +901,23 @@
 (ert-deftest py-ert--fill-fix-end-functionp-test-M5IhuJ ()
   (should (functionp 'py--fill-fix-end)))
 
-(ert-deftest py-ert--fill-docstring-base-functionp-test-IpZrbu ()
-  (should (functionp 'py--fill-docstring-base)))
+;; (ert-deftest py-ert--fill-docstring-final-functionp-test-IpZrbu ()
+;;   (should (functionp 'py--fill-docstring-final)))
 
-(ert-deftest py-ert--fill-docstring-last-line-functionp-test-muOXPe ()
-  (should (functionp 'py--fill-docstring-last-line)))
+;; (ert-deftest py-ert--fill-docstring-last-line-functionp-test-muOXPe ()
+;;   (should (functionp 'py--fill-docstring-last-line)))
 
-(ert-deftest py-ert--fill-docstring-first-line-functionp-test-qWOksZ ()
-  (should (functionp 'py--fill-docstring-first-line)))
+;; (ert-deftest py-ert--fill-docstring-first-line-functionp-test-qWOksZ ()
+;;   (should (functionp 'py--fill-docstring-first-line)))
 
-(ert-deftest py-ert--fill-docstring-functionp-test-uW8Q0J ()
-  (should (functionp 'py--fill-docstring)))
+;; (ert-deftest py-ert--fill-docstring-functionp-test-uW8Q0J ()
+;;   (should (functionp 'py--fill-docstring)))
 
-(ert-deftest py-ert-fill-string-functionp-test-iiS8wu ()
-  (should (functionp 'py-fill-string)))
+;; (ert-deftest py-ert-fill-string-functionp-test-iiS8wu ()
+;;   (should (functionp 'py-fill-string)))
 
-(ert-deftest py-ert-fill-paragraph-functionp-test-e4M60e ()
-  (should (functionp 'py-fill-paragraph)))
+;; (ert-deftest py-ert-fill-paragraph-functionp-test-e4M60e ()
+;;   (should (functionp 'py-fill-paragraph)))
 
 (ert-deftest py-ert-insert-default-shebang-functionp-test-kvspuZ ()
   (should (functionp 'py-insert-default-shebang)))
@@ -1027,9 +979,6 @@
 (ert-deftest py-ert-guess-indent-offset-functionp-test-eQPLcX ()
   (should (functionp 'py-guess-indent-offset)))
 
-(ert-deftest py-ert--comment-indent-function-functionp-test-GCMUVF ()
-  (should (functionp 'py--comment-indent-function)))
-
 (ert-deftest py-ert-backward-paragraph-functionp-test-uaQLCo ()
   (should (functionp 'py-backward-paragraph)))
 
@@ -1240,14 +1189,14 @@
 (ert-deftest py-ert-toggle-sexp-function-functionp-test-ymnQYZ ()
   (should (functionp 'py-toggle-sexp-function)))
 
-(ert-deftest py-ert-toggle-autopair-mode-functionp-test-i4umLM ()
-  (should (functionp 'py-toggle-autopair-mode)))
+;; (ert-deftest py-ert-toggle-autopair-mode-functionp-test-i4umLM ()
+;;   (should (functionp 'py-toggle-autopair-mode)))
 
-(ert-deftest py-ert-autopair-mode-on-functionp-test-GOXfuz ()
-  (should (functionp 'py-autopair-mode-on)))
+;; (ert-deftest py-ert-autopair-mode-on-functionp-test-GOXfuz ()
+;;   (should (functionp 'py-autopair-mode-on)))
 
-(ert-deftest py-ert-autopair-mode-off-functionp-test-cpfpem ()
-  (should (functionp 'py-autopair-mode-off)))
+;; (ert-deftest py-ert-autopair-mode-off-functionp-test-cpfpem ()
+;;   (should (functionp 'py-autopair-mode-off)))
 
 (ert-deftest py-ert-switch-buffers-on-execute-p-on-functionp-test-2hUpEV ()
   (should (functionp 'py-switch-buffers-on-execute-p-on)))
@@ -1417,9 +1366,6 @@
 (ert-deftest py-ert-line-to-printform-python2-functionp-test-oZT4UH ()
   (should (functionp 'py-line-to-printform-python2)))
 
-(ert-deftest py-ert-boolswitch-functionp-test-qWohkw ()
-  (should (functionp 'py-boolswitch)))
-
 (ert-deftest py-ert-end-of-elif-block-functionp-test-YtomSl ()
   (should (functionp 'py-forward-elif-block)))
 
@@ -1504,9 +1450,6 @@
 (ert-deftest py-ert-complete-auto-functionp-test-iybItV ()
   (should (functionp 'py-complete-auto)))
 
-(ert-deftest py-ert-set-command-args-functionp-test-oDb33I ()
-  (should (functionp 'py-set-command-args)))
-
 (ert-deftest py-ert-emacs-version-greater-23-functionp-test-AnhhAw ()
   (should (functionp 'py---emacs-version-greater-23)))
 
@@ -1711,11 +1654,11 @@
 (ert-deftest py-ert-pylint-doku-functionp-test-uS6sE5 ()
   (should (functionp 'py-pylint-doku)))
 
-(ert-deftest py-ert-pyflakes-run-functionp-test-Gue4cX ()
-  (should (functionp 'py-pyflakes-run)))
+(ert-deftest py-ert-pyflakes3-run-functionp-test-Gue4cX ()
+  (should (functionp 'py-pyflakes3-run)))
 
-(ert-deftest py-ert-pyflakes-help-functionp-test-iuxwJO ()
-  (should (functionp 'py-pyflakes-help)))
+(ert-deftest py-ert-pyflakes3-help-functionp-test-iuxwJO ()
+  (should (functionp 'py-pyflakes3-help)))
 
 (ert-deftest py-ert-pyflakespep8-run-functionp-test-oNAJgG ()
   (should (functionp 'py-pyflakespep8-run)))
@@ -2063,9 +2006,6 @@
 (ert-deftest py-ert-py-smart-indentation-on-functionp-test ()   (should (functionp 'py-smart-indentation-on)))
 (ert-deftest py-ert-py-smart-indentation-off-functionp-test ()   (should (functionp 'py-smart-indentation-off)))
 (ert-deftest py-ert-py-toggle-sexp-function-functionp-test ()   (should (functionp 'py-toggle-sexp-function)))
-(ert-deftest py-ert-py-toggle-autopair-mode-functionp-test ()   (should (functionp 'py-toggle-autopair-mode)))
-(ert-deftest py-ert-py-autopair-mode-on-functionp-test ()   (should (functionp 'py-autopair-mode-on)))
-(ert-deftest py-ert-py-autopair-mode-off-functionp-test ()   (should (functionp 'py-autopair-mode-off)))
 (ert-deftest py-ert-py-toggle-switch-buffers-on-execute-p-functionp-test ()   (should (functionp 'py-toggle-switch-buffers-on-execute-p)))
 (ert-deftest py-ert-py-switch-buffers-on-execute-p-on-functionp-test ()   (should (functionp 'py-switch-buffers-on-execute-p-on)))
 (ert-deftest py-ert-py-switch-buffers-on-execute-p-off-functionp-test ()   (should (functionp 'py-switch-buffers-on-execute-p-off)))
