@@ -45,7 +45,7 @@
        'py-nested-block-or-clause-test
        'py-highlight-indentation-test
        'py-smart-indentation-test
-       'autopair-mode-test
+       ;; 'autopair-mode-test
        'py-execute-block-python-test
        'py-execute-statement-error-test
        'py-shell-complete-test
@@ -422,7 +422,7 @@ print(\'\\xA9\')
 (defun UnicodeEncodeError-python3-base (&optional arg)
   (py-execute-region 50 63)
   (set-buffer "*Python3*")
-  ;; (sit-for 1 t)
+  ;; (sit-for 0.1 t)
   ;; (switch-to-buffer (current-buffer))
   (if comint-last-output-start
       (goto-char comint-last-output-start)
@@ -1570,19 +1570,19 @@ def fooBaz( bar ):  # version 2003/9/7
   (assert (eq 2 (py-guess-indent-offset)) nil "py-guess-indent-offset-test #5 failed")
   (message "%s" "py-guess-indent-offset-test #5 done"))
 
-(defun autopair-mode-test (&optional arg)
-  (interactive "p")
-  (let ((teststring "#! /usr/bin/env python
-# -*- coding: utf-8 -*-
+;; (defun autopair-mode-test (&optional arg)
+;;   (interactive "p")
+;;   (let ((teststring "#! /usr/bin/env python
+;; # -*- coding: utf-8 -*-
 
-"))
-  (py-bug-tests-intern 'autopair-on-base arg teststring)))
+;; "))
+;;   (py-bug-tests-intern 'autopair-on-base arg teststring)))
 
-(defun autopair-on-base (arg)
-  (assert (py-autopair-mode-on) nil "autopair-mode-test #1 failed")
-  (message "%s" "autopair-mode-test #1  done")
-  (assert (not (py-toggle-autopair-mode)) nil "autopair-mode-test #2 failed"))
-  (message "%s" "autopair-mode-test #2  done")
+;; (defun autopair-on-base (arg)
+;;   (assert (py-autopair-mode-on) nil "autopair-mode-test #1 failed")
+;;   (message "%s" "autopair-mode-test #1  done")
+;;   (assert (not (py-toggle-autopair-mode)) nil "autopair-mode-test #2 failed"))
+  ;; (message "%s" "autopair-mode-test #2  done")
 
 (defun py-smart-indentation-test (&optional arg)
   (interactive "p")
@@ -1972,7 +1972,7 @@ else:
     (push-mark)
     (end-of-line)
     (setq erg (py-execute-statement-python))
-    ;; (sit-for 1 t)
+    ;; (sit-for 0.1 t)
     (set-buffer "*Python*")
     ;; (sit-for 0.3 t)
     (when py-debug-p (switch-to-buffer (current-buffer)))
